@@ -1,6 +1,8 @@
 """CLI - Command Line Interface"""
+from snakypy.zshpower.commands.cron import Cron
+
 try:
-    from snakypy.helpers.decorators import only_linux, silent_errors
+    from snakypy.helpers.decorators import only_linux
 except KeyboardInterrupt:
     pass
 from snakypy.zshpower import HOME
@@ -22,7 +24,7 @@ args: dict = arguments()
 
 @assign_cli(args, "init")
 def run_init() -> None:
-    InitCommand(HOME).run(args, reload=True, message=True)
+    InitCommand(HOME).run(args, reload=True)
 
 
 @assign_cli(args, "config")
@@ -55,6 +57,11 @@ def run_sync() -> None:
     Sync(HOME).run()
 
 
+@assign_cli(args, "cron")
+def run_cron() -> None:
+    Cron(HOME).run(args)
+
+
 @assign_cli(args, "logs")
 def run_logs() -> None:
     LogsCommand(HOME).run(args)
@@ -65,7 +72,7 @@ def run_credits() -> None:
     CreditsCommand().run()
 
 
-@silent_errors
+# @silent_errors
 @only_linux
 def main() -> None:
     run_init()
@@ -75,5 +82,6 @@ def main() -> None:
     run_reset()
     run_uninstall()
     run_sync()
+    run_cron()
     run_logs()
     run_credits()
