@@ -1,3 +1,4 @@
+from contextlib import suppress
 from os import remove, symlink
 from os.path import islink, join
 from sys import stdout
@@ -45,7 +46,12 @@ class InitCommand(Base):
 
     def run(self, arguments, *, reload=False) -> None:
         tools_requirements("bash", "zsh", "vim", "git", "cut", "grep", "whoami", "pwd")
-        create_file(zshrc_sample, self.zsh_rc)
+
+        # If there is, an exception will not pop.
+        with suppress(FileExistsError):
+            create_file(zshrc_sample, self.zsh_rc)
+
+        # Returns only the path
         if arguments["--path"]:
             stdout.write(
                 join(f'[[ -d "{self.lib_root}" ]] && source $HOME', self.source_code)
