@@ -2,11 +2,11 @@ from pydoc import pager
 
 from snakypy.helpers import printer
 from snakypy.helpers.ansi import FG
-from snakypy.helpers.files import read_file
+from snakypy.helpers.files import create_file, read_file
+from snakypy.helpers.os.removals import remove_objects
 
 from snakypy.zshpower.config.base import Base
 from snakypy.zshpower.utils.check import checking_init
-from snakypy.zshpower.utils.shift import log_base
 
 
 class LogsCommand(Base):
@@ -16,8 +16,12 @@ class LogsCommand(Base):
     def run(self, arguments) -> None:
         checking_init(self.HOME, self.logfile)
         if arguments["--view"]:
-            read_logs = read_file(self.logfile)
-            pager(read_logs)
+            try:
+                read_logs = read_file(self.logfile)
+                pager(read_logs)
+            except FileNotFoundError:
+                printer("Log files not found:", foreground=FG().WARNING)
         elif arguments["--clean"]:
-            log_base(self.logfile, force=True)
+            remove_objects(objects=(self.logfile,))
+            create_file("", self.logfile, force=True)
             printer("Logs have been cleaned up.", foreground=FG().FINISH)
