@@ -1,9 +1,10 @@
 from subprocess import run
 
+from snakypy.zshpower.config.base import Base
 from snakypy.zshpower.prompt.sections.utils import Version
 
 
-class CMake(Version):
+class CMake(Version, Base):
     def __init__(self):
         super(CMake, self).__init__()
         self.files = ("CMakeLists.txt", "CMakeCache.txt")
@@ -11,13 +12,7 @@ class CMake(Version):
     def get_version(self, config, version, key="cmake", ext="cm-", space_elem=" "):
         return super().get(config, version, key=key, ext=ext, space_elem=space_elem)
 
-    def set_version(self, key="cmake", action=None):
-        version = run(
-            "cmake --version 2>&1", capture_output=True, shell=True, text=True
-        )
-        if not version.returncode == 0:
-            return False
-
-        version = version.stdout.split()[2]
-
-        return super().set(version, key, action)
+    def set_version(self, exec_="cmake", key="cmake", action=None):
+        command = run("cmake --version", capture_output=True, shell=True, text=True)
+        version = command.stdout.split()[2]
+        return super().set(command, version, exec_, key, action)
