@@ -1,9 +1,10 @@
 from subprocess import run
 
+from snakypy.zshpower.config.base import Base
 from snakypy.zshpower.prompt.sections.utils import Version
 
 
-class Helm(Version):
+class Helm(Version, Base):
     def __init__(self):
         super(Helm, self).__init__()
         self.files = ("helmfile.yaml", "Chart.yaml")
@@ -13,11 +14,7 @@ class Helm(Version):
     ) -> str:
         return super().get(config, reg_version, key=key, ext=ext, space_elem=space_elem)
 
-    def set_version(self, key="helm", action=None) -> bool:
-        version = run("helm version 2>&1", capture_output=True, shell=True, text=True)
-
-        if version.returncode != 127 and version.returncode != 1:
-            version_format = version.stdout.split(":")[1].split('"')[1].replace("v", "")
-            return super().set(version_format, key, action)
-
-        return False
+    def set_version(self, exec_="helm", key="helm", action=None) -> bool:
+        command = run("helm version", capture_output=True, shell=True, text=True)
+        version = command.stdout.split(":")[1].split('"')[1].replace("v", "")
+        return super().set(command, version, exec_, key, action)
