@@ -1,9 +1,10 @@
 from subprocess import run
 
+from snakypy.zshpower.config.base import Base
 from snakypy.zshpower.prompt.sections.utils import Version
 
 
-class Julia(Version):
+class Julia(Version, Base):
     def __init__(self):
         super(Julia, self).__init__()
         self.extensions = (".jl",)
@@ -13,11 +14,7 @@ class Julia(Version):
     ) -> str:
         return super().get(config, reg_version, key=key, ext=ext, space_elem=space_elem)
 
-    def set_version(self, key="julia", action=None) -> bool:
-        version = run("julia --version", capture_output=True, shell=True, text=True)
-
-        if version.returncode != 127 and version.returncode != 1:
-            version_format = version.stdout.replace("\n", "").split(" ")[2]
-            return super().set(version_format, key, action)
-
-        return False
+    def set_version(self, exec_="julia", key="julia", action=None):
+        command = run("julia --version", capture_output=True, shell=True, text=True)
+        version = command.stdout.replace("\n", "").split(" ")[2]
+        return super().set(command, version, exec_, key, action)
